==> kdepim_4.13.0.orig.tar.xz: kdepim-4.13.0/libksieve/ksieveui/editor/tests/editorsieve_gui.cpp <==
/*
  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "editorsieve_gui.h"
#include <kdebug.h>
#include <kcmdlineargs.h>
#include <kapplication.h>
#include <QDebug>
#include "ksieveui/editor/sieveeditor.h"
#include "pimcommon/sievehighlighter/sievesyntaxhighlighterutil.h"




int main (int argc, char **argv)
{
    KCmdLineArgs::init(argc, argv, "editorsieve_gui", 0, ki18n("EditorSievetest_Gui"),
                       "1.0", ki18n("Test for editor sieve dialog"));
    KApplication app;
    SieveEditorTestWidget *dialog = new SieveEditorTestWidget;
    const QStringList capabilities = PimCommon::SieveSyntaxHighlighterUtil::fullCapabilities();
    //Add all capabilities for testing
    dialog->setSieveCapabilities(capabilities);
    if (dialog->exec() ) {
        qDebug()<<" generated script :\n"<<dialog->script()<<"\n";
    }
    delete dialog;
    return 0;
}



SieveEditorTestWidget::SieveEditorTestWidget(QWidget *parent)
    : KSieveUi::SieveEditor(parent)
{
    connect(this, SIGNAL(valueChanged()), this, SLOT(slotValueChanged()));
}

SieveEditorTestWidget::~SieveEditorTestWidget()
{

}

void SieveEditorTestWidget::slotValueChanged()
{
    qDebug()<<" value changed";
}

==> kdepim_4.14.2.orig.tar.xz: kdepim-4.14.2/libksieve/ksieveui/editor/tests/editorsieve_gui.cpp <==
/*
  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "editorsieve_gui.h"
#include <kdebug.h>
#include <kcmdlineargs.h>
#include <kapplication.h>
#include <QDebug>
#include "ksieveui/editor/sieveeditor.h"
#include "pimcommon/sievehighlighter/sievesyntaxhighlighterutil.h"




int main (int argc, char **argv)
{
    KCmdLineArgs::init(argc, argv, "editorsieve_gui", 0, ki18n("EditorSievetest_Gui"),
                       "1.0", ki18n("Test for editor sieve dialog"));
    KApplication app;
    SieveEditorTestWidget *dialog = new SieveEditorTestWidget;
    const QStringList capabilities = PimCommon::SieveSyntaxHighlighterUtil::fullCapabilities();
    //Add all capabilities for testing
    dialog->setSieveCapabilities(capabilities);
    if (dialog->exec() ) {
        qDebug()<<" generated script :\n"<<dialog->script()<<"\n";
    }
    delete dialog;
    return 0;
}



SieveEditorTestWidget::SieveEditorTestWidget(QWidget *parent)
    : KSieveUi::SieveEditor(parent)
{
    connect(this, SIGNAL(valueChanged(bool)), this, SLOT(slotValueChanged(bool)));
}

SieveEditorTestWidget::~SieveEditorTestWidget()
{

}

void SieveEditorTestWidget::slotValueChanged(bool changed)
{
    qDebug()<<" value changed :"<<changed;
}
